@@ -32,14 +32,15 @@
 WeatherComStation wcs = { NULL };
 /*******************************************************************************/
 Item* create_item(const char *name, const char *value){
-    Item	*itm;
+    Item	*itm = NULL;
 
     if(!name)
 	return NULL;
     
     itm = g_new0(Item, 1);
     itm->name = g_string_new(name);
-    value && (itm->value = g_string_new(value));
+    if(value)
+	itm->value = g_string_new(value);
     return itm;
 }
 /*******************************************************************************/
@@ -50,6 +51,7 @@ void destroy_item(Item **item){
 	g_string_free((*item)->name, TRUE);
     if((*item)->value)
 	g_string_free((*item)->value, TRUE);
+
     g_free(*item);
     *item = NULL;
 }
