@@ -665,7 +665,6 @@ void weather_buttons_fill(gboolean check_error){
     #endif 
     if(error_station_code){
 	station_error_window();
-	weather_window_settings(NULL, NULL, NULL);
     }
 #ifndef RELEASE
     fprintf(stderr,"END %s(): \n", __PRETTY_FUNCTION__);
@@ -709,6 +708,11 @@ void* hildon_home_applet_lib_initialize(void *state_data, int *state_size,
         g_debug(_("Error initializing the OMWeather applet"));
         return NULL;
     }
+/* Checking noomweather.txt file */
+    if ((access("/media/mmc1/noomweather.txt", R_OK) == 0)||
+        (access("/media/mmc2/noomweather.txt", R_OK) == 0))
+        return NULL;
+    
 #ifndef RELEASE
 	fprintf(stderr, "\nOMWeather applet initialize %p %d\n",
 			state_data, *state_size);
