@@ -319,7 +319,7 @@ int new_parse_weather_com_xml(void){
 	    }
 	    /* Fill other days */
 	    if(!xmlStrcmp(cur_node->name, (const xmlChar *) "dayf" ) ){
-    		for(child_node = cur_node->children; child_node; child_node = child_node->next){
+		for(child_node = cur_node->children; child_node  && count_day <= Max_count_weather_day; child_node = child_node->next){
     		    if( child_node->type == XML_ELEMENT_NODE  &&
 			    ( !xmlStrcmp(child_node->name, (const xmlChar *)"day") ) ){
 			/* get 24h name */
