@@ -779,10 +779,15 @@ void weather_window_settings(GtkWidget *widget,	GdkEvent *event,
 #endif
 /* Up Station and Down Station Buttons */
 /* prepare icon */
+#ifdef HILDON
     gtkicon_arrow = gtk_icon_theme_lookup_icon(gtk_icon_theme_get_default(),
         	                        	"qgn_indi_arrow_up", 16, 0);
     up_icon = gtk_image_new_from_file(gtk_icon_info_get_filename(gtkicon_arrow));
     gtk_icon_info_free(gtkicon_arrow);
+#else
+     up_icon = gtk_image_new_from_stock(GTK_STOCK_GO_UP, GTK_ICON_SIZE_BUTTON);
+#endif      
+
 /* prepare up_station_button */    
     up_station_button = gtk_button_new();
     gtk_button_set_focus_on_click(GTK_BUTTON(up_station_button), FALSE);
@@ -793,10 +798,15 @@ void weather_window_settings(GtkWidget *widget,	GdkEvent *event,
     gtk_table_attach_defaults(GTK_TABLE(table), up_station_button,
         			1, 2, 2, 3);
 /* prepare icon */
+#ifdef HILDON
     gtkicon_arrow = gtk_icon_theme_lookup_icon(gtk_icon_theme_get_default(),
         	                        	"qgn_indi_arrow_down", 16, 0);
     down_icon = gtk_image_new_from_file(gtk_icon_info_get_filename(gtkicon_arrow));
     gtk_icon_info_free(gtkicon_arrow);
+#else
+    down_icon = gtk_image_new_from_stock(GTK_STOCK_GO_DOWN, GTK_ICON_SIZE_BUTTON);
+#endif    
+
 /* prepare down_station_button */    
     down_station_button = gtk_button_new();
     gtk_button_set_focus_on_click(GTK_BUTTON(down_station_button), FALSE);
